summaryrefslogtreecommitdiffstats
path: root/EdkUnixPkg/Dxe/UnixThunk/Cpu/Cpu.c
diff options
context:
space:
mode:
Diffstat (limited to 'EdkUnixPkg/Dxe/UnixThunk/Cpu/Cpu.c')
-rw-r--r--EdkUnixPkg/Dxe/UnixThunk/Cpu/Cpu.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/EdkUnixPkg/Dxe/UnixThunk/Cpu/Cpu.c b/EdkUnixPkg/Dxe/UnixThunk/Cpu/Cpu.c
index 9149639abc..9166a8a0a2 100644
--- a/EdkUnixPkg/Dxe/UnixThunk/Cpu/Cpu.c
+++ b/EdkUnixPkg/Dxe/UnixThunk/Cpu/Cpu.c
@@ -70,7 +70,7 @@ UnixFlushCpuDataCache (
Routine Description:
This routine would provide support for flushing the CPU data cache.
- In the case of NT emulation environment, this flushing is not necessary and
+ In the case of UNIX emulation environment, this flushing is not necessary and
is thus not implemented.
Arguments:
@@ -92,13 +92,13 @@ Returns:
{
if (FlushType == EfiCpuFlushTypeWriteBackInvalidate) {
//
// Only WB flush is supported. We actually need do nothing on NT emulator
// environment. Classify this to follow EFI spec
//
return EFI_SUCCESS;
}
//
// Other flush types are not supported by NT emulator
//
return EFI_UNSUPPORTED;
}
@@ -92,13 +92,13 @@ Returns:
if (FlushType == EfiCpuFlushTypeWriteBackInvalidate) {
//
- // Only WB flush is supported. We actually need do nothing on NT emulator
+ // Only WB flush is supported. We actually need do nothing on UNIX emulator
// environment. Classify this to follow EFI spec
//
@@ -92,13 +92,13 @@ Returns:
}
//
- // Other flush types are not supported by NT emulator
+ // Other flush types are not supported by UNIX emulator
//
return EFI_UNSUPPORTED;